mailr22853 - /trunk/specific_analyses/relax_disp/optimisation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on April 24, 2014 - 17:38:
Author: bugman
Date: Thu Apr 24 17:38:33 2014
New Revision: 22853

URL: http://svn.gna.org/viewcvs/relax?rev=22853&view=rev
Log:
Changed the bounds for the R20 parameters in the default grid search.

The range of 1 to 40 rad.s^-1 was previous used.  This has been narrowed to 5 
to 20.


Modified:
    trunk/specific_analyses/relax_disp/optimisation.py

Modified: trunk/specific_analyses/relax_disp/optimisation.py
URL: 
http://svn.gna.org/viewcvs/relax/trunk/specific_analyses/relax_disp/optimisation.py?rev=22853&r1=22852&r2=22853&view=diff
==============================================================================
--- trunk/specific_analyses/relax_disp/optimisation.py  (original)
+++ trunk/specific_analyses/relax_disp/optimisation.py  Thu Apr 24 17:38:33 
2014
@@ -326,10 +326,10 @@
                 if si == None:
                     si = 0
 
                 # R2 relaxation rates (from 1 to 40 s^-1).
                 if param_name in ['r2', 'r2a', 'r2b']:
-                    lower.append(1.0)
-                    upper.append(40.0)
+                    lower.append(5.0)
+                    upper.append(20.0)
 
                 # The pA.pB.dw**2 and pA.dw**2 parameters.
                 elif param_name in ['phi_ex', 'phi_ex_B', 'phi_ex_C', 
@@ -326,10 +326,10 @@
                     si = 0
 
-                # R2 relaxation rates (from 1 to 40 s^-1).
+                # R2 relaxation rates (from 5 to 20 s^-1).
                 if param_name in ['r2', 'r2a', 'r2b']:
'padw2']:




Related Messages


Powered by MHonArc, Updated Fri Apr 25 15:40:02 2014